import typing

import typing_extensions

_list = list

@typing.type_check_only
class Activity(typing_extensions.TypedDict, total=False):
    activityTime: str
    activityType: typing_extensions.Literal[
        "ACTIVITY_TYPE_UNSPECIFIED",
        "PAGEVIEW",
        "SCREENVIEW",
        "GOAL",
        "ECOMMERCE",
        "EVENT",
    ]
    appview: ScreenviewData
    campaign: str
    channelGrouping: str
    customDimension: _list[CustomDimension]
    ecommerce: EcommerceData
    event: EventData
    goals: GoalSetData
    hostname: str
    keyword: str
    landingPagePath: str
    medium: str
    pageview: PageviewData
    source: str

@typing.type_check_only
class Cohort(typing_extensions.TypedDict, total=False):
    dateRange: DateRange
    name: str
    type: typing_extensions.Literal["UNSPECIFIED_COHORT_TYPE", "FIRST_VISIT_DATE"]

@typing.type_check_only
class CohortGroup(typing_extensions.TypedDict, total=False):
    cohorts: _list[Cohort]
    lifetimeValue: bool

@typing.type_check_only
class ColumnHeader(typing_extensions.TypedDict, total=False):
    dimensions: _list[str]
    metricHeader: MetricHeader

@typing.type_check_only
class CustomDimension(typing_extensions.TypedDict, total=False):
    index: int
    value: str

@typing.type_check_only
class DateRange(typing_extensions.TypedDict, total=False):
    endDate: str
    startDate: str

@typing.type_check_only
class DateRangeValues(typing_extensions.TypedDict, total=False):
    pivotValueRegions: _list[PivotValueRegion]
    values: _list[str]

@typing.type_check_only
class Dimension(typing_extensions.TypedDict, total=False):
    histogramBuckets: _list[str]
    name: str

AlternativeDimensionFilter = typing_extensions.TypedDict(
    "AlternativeDimensionFilter",
    {
        "caseSensitive": bool,
        "dimensionName": str,
        "expressions": _list[str],
        "not": bool,
        "operator": typing_extensions.Literal[
            "OPERATOR_UNSPECIFIED",
            "REGEXP",
            "BEGINS_WITH",
            "ENDS_WITH",
            "PARTIAL",
            "EXACT",
            "NUMERIC_EQUAL",
            "NUMERIC_GREATER_THAN",
            "NUMERIC_LESS_THAN",
            "IN_LIST",
        ],
    },
    total=False,
)

@typing.type_check_only
class DimensionFilter(AlternativeDimensionFilter): ...

@typing.type_check_only
class DimensionFilterClause(typing_extensions.TypedDict, total=False):
    filters: _list[DimensionFilter]
    operator: typing_extensions.Literal["OPERATOR_UNSPECIFIED", "OR", "AND"]

@typing.type_check_only
class DynamicSegment(typing_extensions.TypedDict, total=False):
    name: str
    sessionSegment: SegmentDefinition
    userSegment: SegmentDefinition

@typing.type_check_only
class EcommerceData(typing_extensions.TypedDict, total=False):
    actionType: typing_extensions.Literal[
        "UNKNOWN",
        "CLICK",
        "DETAILS_VIEW",
        "ADD_TO_CART",
        "REMOVE_FROM_CART",
        "CHECKOUT",
        "PAYMENT",
        "REFUND",
        "CHECKOUT_OPTION",
    ]
    ecommerceType: typing_extensions.Literal[
        "ECOMMERCE_TYPE_UNSPECIFIED", "CLASSIC", "ENHANCED"
    ]
    products: _list[ProductData]
    transaction: TransactionData

@typing.type_check_only
class EventData(typing_extensions.TypedDict, total=False):
    eventAction: str
    eventCategory: str
    eventCount: str
    eventLabel: str
    eventValue: str

@typing.type_check_only
class GetReportsRequest(typing_extensions.TypedDict, total=False):
    reportRequests: _list[ReportRequest]
    useResourceQuotas: bool

@typing.type_check_only
class GetReportsResponse(typing_extensions.TypedDict, total=False):
    queryCost: int
    reports: _list[Report]
    resourceQuotasRemaining: ResourceQuotasRemaining

@typing.type_check_only
class GoalData(typing_extensions.TypedDict, total=False):
    goalCompletionLocation: str
    goalCompletions: str
    goalIndex: int
    goalName: str
    goalPreviousStep1: str
    goalPreviousStep2: str
    goalPreviousStep3: str
    goalValue: float

@typing.type_check_only
class GoalSetData(typing_extensions.TypedDict, total=False):
    goals: _list[GoalData]

@typing.type_check_only
class Metric(typing_extensions.TypedDict, total=False):
    alias: str
    expression: str
    formattingType: typing_extensions.Literal[
        "METRIC_TYPE_UNSPECIFIED", "INTEGER", "FLOAT", "CURRENCY", "PERCENT", "TIME"
    ]

AlternativeMetricFilter = typing_extensions.TypedDict(
    "AlternativeMetricFilter",
    {
        "comparisonValue": str,
        "metricName": str,
        "not": bool,
        "operator": typing_extensions.Literal[
            "OPERATOR_UNSPECIFIED", "EQUAL", "LESS_THAN", "GREATER_THAN", "IS_MISSING"
        ],
    },
    total=False,
)

@typing.type_check_only
class MetricFilter(AlternativeMetricFilter): ...

@typing.type_check_only
class MetricFilterClause(typing_extensions.TypedDict, total=False):
    filters: _list[MetricFilter]
    operator: typing_extensions.Literal["OPERATOR_UNSPECIFIED", "OR", "AND"]

@typing.type_check_only
class MetricHeader(typing_extensions.TypedDict, total=False):
    metricHeaderEntries: _list[MetricHeaderEntry]
    pivotHeaders: _list[PivotHeader]

@typing.type_check_only
class MetricHeaderEntry(typing_extensions.TypedDict, total=False):
    name: str
    type: typing_extensions.Literal[
        "METRIC_TYPE_UNSPECIFIED", "INTEGER", "FLOAT", "CURRENCY", "PERCENT", "TIME"
    ]

@typing.type_check_only
class OrFiltersForSegment(typing_extensions.TypedDict, total=False):
    segmentFilterClauses: _list[SegmentFilterClause]

@typing.type_check_only
class OrderBy(typing_extensions.TypedDict, total=False):
    fieldName: str
    orderType: typing_extensions.Literal[
        "ORDER_TYPE_UNSPECIFIED",
        "VALUE",
        "DELTA",
        "SMART",
        "HISTOGRAM_BUCKET",
        "DIMENSION_AS_INTEGER",
    ]
    sortOrder: typing_extensions.Literal[
        "SORT_ORDER_UNSPECIFIED", "ASCENDING", "DESCENDING"
    ]

@typing.type_check_only
class PageviewData(typing_extensions.TypedDict, total=False):
    pagePath: str
    pageTitle: str

@typing.type_check_only
class Pivot(typing_extensions.TypedDict, total=False):
    dimensionFilterClauses: _list[DimensionFilterClause]
    dimensions: _list[Dimension]
    maxGroupCount: int
    metrics: _list[Metric]
    startGroup: int

@typing.type_check_only
class PivotHeader(typing_extensions.TypedDict, total=False):
    pivotHeaderEntries: _list[PivotHeaderEntry]
    totalPivotGroupsCount: int

@typing.type_check_only
class PivotHeaderEntry(typing_extensions.TypedDict, total=False):
    dimensionNames: _list[str]
    dimensionValues: _list[str]
    metric: MetricHeaderEntry

@typing.type_check_only
class PivotValueRegion(typing_extensions.TypedDict, total=False):
    values: _list[str]

@typing.type_check_only
class ProductData(typing_extensions.TypedDict, total=False):
    itemRevenue: float
    productName: str
    productQuantity: str
    productSku: str

@typing.type_check_only
class Report(typing_extensions.TypedDict, total=False):
    columnHeader: ColumnHeader
    data: ReportData
    nextPageToken: str

@typing.type_check_only
class ReportData(typing_extensions.TypedDict, total=False):
    dataLastRefreshed: str
    emptyReason: str
    isDataGolden: bool
    maximums: _list[DateRangeValues]
    minimums: _list[DateRangeValues]
    rowCount: int
    rows: _list[ReportRow]
    samplesReadCounts: _list[str]
    samplingSpaceSizes: _list[str]
    totals: _list[DateRangeValues]

@typing.type_check_only
class ReportRequest(typing_extensions.TypedDict, total=False):
    cohortGroup: CohortGroup
    dateRanges: _list[DateRange]
    dimensionFilterClauses: _list[DimensionFilterClause]
    dimensions: _list[Dimension]
    filtersExpression: str
    hideTotals: bool
    hideValueRanges: bool
    includeEmptyRows: bool
    metricFilterClauses: _list[MetricFilterClause]
    metrics: _list[Metric]
    orderBys: _list[OrderBy]
    pageSize: int
    pageToken: str
    pivots: _list[Pivot]
    samplingLevel: typing_extensions.Literal[
        "SAMPLING_UNSPECIFIED", "DEFAULT", "SMALL", "LARGE"
    ]
    segments: _list[Segment]
    viewId: str

@typing.type_check_only
class ReportRow(typing_extensions.TypedDict, total=False):
    dimensions: _list[str]
    metrics: _list[DateRangeValues]

@typing.type_check_only
class ResourceQuotasRemaining(typing_extensions.TypedDict, total=False):
    dailyQuotaTokensRemaining: int
    hourlyQuotaTokensRemaining: int

@typing.type_check_only
class ScreenviewData(typing_extensions.TypedDict, total=False):
    appName: str
    mobileDeviceBranding: str
    mobileDeviceModel: str
    screenName: str

@typing.type_check_only
class SearchUserActivityRequest(typing_extensions.TypedDict, total=False):
    activityTypes: _list[str]
    dateRange: DateRange
    pageSize: int
    pageToken: str
    user: User
    viewId: str

@typing.type_check_only
class SearchUserActivityResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    sampleRate: float
    sessions: _list[UserActivitySession]
    totalRows: int

@typing.type_check_only
class Segment(typing_extensions.TypedDict, total=False):
    dynamicSegment: DynamicSegment
    segmentId: str

@typing.type_check_only
class SegmentDefinition(typing_extensions.TypedDict, total=False):
    segmentFilters: _list[SegmentFilter]

@typing.type_check_only
class SegmentDimensionFilter(typing_extensions.TypedDict, total=False):
    caseSensitive: bool
    dimensionName: str
    expressions: _list[str]
    maxComparisonValue: str
    minComparisonValue: str
    operator: typing_extensions.Literal[
        "OPERATOR_UNSPECIFIED",
        "REGEXP",
        "BEGINS_WITH",
        "ENDS_WITH",
        "PARTIAL",
        "EXACT",
        "IN_LIST",
        "NUMERIC_LESS_THAN",
        "NUMERIC_GREATER_THAN",
        "NUMERIC_BETWEEN",
    ]

AlternativeSegmentFilter = typing_extensions.TypedDict(
    "AlternativeSegmentFilter",
    {
        "not": bool,
        "sequenceSegment": SequenceSegment,
        "simpleSegment": SimpleSegment,
    },
    total=False,
)

@typing.type_check_only
class SegmentFilter(AlternativeSegmentFilter): ...

AlternativeSegmentFilterClause = typing_extensions.TypedDict(
    "AlternativeSegmentFilterClause",
    {
        "dimensionFilter": SegmentDimensionFilter,
        "metricFilter": SegmentMetricFilter,
        "not": bool,
    },
    total=False,
)

@typing.type_check_only
class SegmentFilterClause(AlternativeSegmentFilterClause): ...

@typing.type_check_only
class SegmentMetricFilter(typing_extensions.TypedDict, total=False):
    comparisonValue: str
    maxComparisonValue: str
    metricName: str
    operator: typing_extensions.Literal[
        "UNSPECIFIED_OPERATOR", "LESS_THAN", "GREATER_THAN", "EQUAL", "BETWEEN"
    ]
    scope: typing_extensions.Literal[
        "UNSPECIFIED_SCOPE", "PRODUCT", "HIT", "SESSION", "USER"
    ]

@typing.type_check_only
class SegmentSequenceStep(typing_extensions.TypedDict, total=False):
    matchType: typing_extensions.Literal[
        "UNSPECIFIED_MATCH_TYPE", "PRECEDES", "IMMEDIATELY_PRECEDES"
    ]
    orFiltersForSegment: _list[OrFiltersForSegment]

@typing.type_check_only
class SequenceSegment(typing_extensions.TypedDict, total=False):
    firstStepShouldMatchFirstHit: bool
    segmentSequenceSteps: _list[SegmentSequenceStep]

@typing.type_check_only
class SimpleSegment(typing_extensions.TypedDict, total=False):
    orFiltersForSegment: _list[OrFiltersForSegment]

@typing.type_check_only
class TransactionData(typing_extensions.TypedDict, total=False):
    transactionId: str
    transactionRevenue: float
    transactionShipping: float
    transactionTax: float

@typing.type_check_only
class User(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["USER_ID_TYPE_UNSPECIFIED", "USER_ID", "CLIENT_ID"]
    userId: str

@typing.type_check_only
class UserActivitySession(typing_extensions.TypedDict, total=False):
    activities: _list[Activity]
    dataSource: str
    deviceCategory: str
    platform: str
    sessionDate: str
    sessionId: str



from _typeshed import Incomplete

from ..discovery_cache import DISCOVERY_DOC_MAX_AGE as DISCOVERY_DOC_MAX_AGE
from . import base as base

LOGGER: Incomplete
NAMESPACE: str

class Cache(base.Cache):
    def __init__(self, max_age) -> None: ...
    def get(self, url): ...
    def set(self, url, content) -> None: ...

cache: Incomplete



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class DatedValue(typing_extensions.TypedDict, total=False):
    date: Date
    value: str

@typing.type_check_only
class GetDailyMetricsTimeSeriesResponse(typing_extensions.TypedDict, total=False):
    timeSeries: TimeSeries

@typing.type_check_only
class InsightsValue(typing_extensions.TypedDict, total=False):
    threshold: str
    value: str

@typing.type_check_only
class ListSearchKeywordImpressionsMonthlyResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    searchKeywordsCounts: _list[SearchKeywordCount]

@typing.type_check_only
class SearchKeywordCount(typing_extensions.TypedDict, total=False):
    insightsValue: InsightsValue
    searchKeyword: str

@typing.type_check_only
class TimeSeries(typing_extensions.TypedDict, total=False):
    datedValues: _list[DatedValue]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class SearchConsoleResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class SearchanalyticsResource(googleapiclient.discovery.Resource):
        def query(
            self,
            *,
            siteUrl: str,
            body: SearchAnalyticsQueryRequest = ...,
            **kwargs: typing.Any
        ) -> SearchAnalyticsQueryResponseHttpRequest: ...

    @typing.type_check_only
    class SitemapsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, siteUrl: str, feedpath: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, siteUrl: str, feedpath: str, **kwargs: typing.Any
        ) -> WmxSitemapHttpRequest: ...
        def list(
            self, *, siteUrl: str, sitemapIndex: str = ..., **kwargs: typing.Any
        ) -> SitemapsListResponseHttpRequest: ...
        def submit(
            self, *, siteUrl: str, feedpath: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class SitesResource(googleapiclient.discovery.Resource):
        def add(
            self, *, siteUrl: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def delete(
            self, *, siteUrl: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(self, *, siteUrl: str, **kwargs: typing.Any) -> WmxSiteHttpRequest: ...
        def list(self, **kwargs: typing.Any) -> SitesListResponseHttpRequest: ...

    @typing.type_check_only
    class UrlInspectionResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class IndexResource(googleapiclient.discovery.Resource):
            def inspect(
                self, *, body: InspectUrlIndexRequest = ..., **kwargs: typing.Any
            ) -> InspectUrlIndexResponseHttpRequest: ...

        def index(self) -> IndexResource: ...

    @typing.type_check_only
    class UrlTestingToolsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class MobileFriendlyTestResource(googleapiclient.discovery.Resource):
            def run(
                self, *, body: RunMobileFriendlyTestRequest = ..., **kwargs: typing.Any
            ) -> RunMobileFriendlyTestResponseHttpRequest: ...

        def mobileFriendlyTest(self) -> MobileFriendlyTestResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def searchanalytics(self) -> SearchanalyticsResource: ...
    def sitemaps(self) -> SitemapsResource: ...
    def sites(self) -> SitesResource: ...
    def urlInspection(self) -> UrlInspectionResource: ...
    def urlTestingTools(self) -> UrlTestingToolsResource: ...

@typing.type_check_only
class InspectUrlIndexResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> InspectUrlIndexResponse: ...

@typing.type_check_only
class RunMobileFriendlyTestResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RunMobileFriendlyTestResponse: ...

@typing.type_check_only
class SearchAnalyticsQueryResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchAnalyticsQueryResponse: ...

@typing.type_check_only
class SitemapsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SitemapsListResponse: ...

@typing.type_check_only
class SitesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SitesListResponse: ...

@typing.type_check_only
class WmxSiteHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WmxSite: ...

@typing.type_check_only
class WmxSitemapHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WmxSitemap: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class BusinessProfilePerformanceResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class SearchkeywordsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ImpressionsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class MonthlyResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        monthlyRange_endMonth_day: int = ...,
                        monthlyRange_endMonth_month: int = ...,
                        monthlyRange_endMonth_year: int = ...,
                        monthlyRange_startMonth_day: int = ...,
                        monthlyRange_startMonth_month: int = ...,
                        monthlyRange_startMonth_year: int = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListSearchKeywordImpressionsMonthlyResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListSearchKeywordImpressionsMonthlyResponseHttpRequest,
                        previous_response: ListSearchKeywordImpressionsMonthlyResponse,
                    ) -> ListSearchKeywordImpressionsMonthlyResponseHttpRequest | None: ...

                def monthly(self) -> MonthlyResource: ...

            def impressions(self) -> ImpressionsResource: ...

        def getDailyMetricsTimeSeries(
            self,
            *,
            name: str,
            dailyMetric: typing_extensions.Literal[
                "DAILY_METRIC_UNKNOWN",
                "BUSINESS_IMPRESSIONS_DESKTOP_MAPS",
                "BUSINESS_IMPRESSIONS_DESKTOP_SEARCH",
                "BUSINESS_IMPRESSIONS_MOBILE_MAPS",
                "BUSINESS_IMPRESSIONS_MOBILE_SEARCH",
                "BUSINESS_CONVERSATIONS",
                "BUSINESS_DIRECTION_REQUESTS",
                "CALL_CLICKS",
                "WEBSITE_CLICKS",
                "BUSINESS_BOOKINGS",
                "BUSINESS_FOOD_ORDERS",
            ] = ...,
            dailyRange_endDate_day: int = ...,
            dailyRange_endDate_month: int = ...,
            dailyRange_endDate_year: int = ...,
            dailyRange_startDate_day: int = ...,
            dailyRange_startDate_month: int = ...,
            dailyRange_startDate_year: int = ...,
            dailySubEntityType_dayOfWeek: typing_extensions.Literal[
                "DAY_OF_WEEK_UNSPECIFIED",
                "MONDAY",
                "TUESDAY",
                "WEDNESDAY",
                "THURSDAY",
                "FRIDAY",
                "SATURDAY",
                "SUNDAY",
            ] = ...,
            dailySubEntityType_timeOfDay_hours: int = ...,
            dailySubEntityType_timeOfDay_minutes: int = ...,
            dailySubEntityType_timeOfDay_nanos: int = ...,
            dailySubEntityType_timeOfDay_seconds: int = ...,
            **kwargs: typing.Any
        ) -> GetDailyMetricsTimeSeriesResponseHttpRequest: ...
        def searchkeywords(self) -> SearchkeywordsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def locations(self) -> LocationsResource: ...

@typing.type_check_only
class GetDailyMetricsTimeSeriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetDailyMetricsTimeSeriesResponse: ...

@typing.type_check_only
class ListSearchKeywordImpressionsMonthlyResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSearchKeywordImpressionsMonthlyResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class CustomApp(typing_extensions.TypedDict, total=False):
    languageCode: str
    organizations: _list[Organization]
    packageName: str
    title: str

@typing.type_check_only
class Organization(typing_extensions.TypedDict, total=False):
    organizationId: str
    organizationName: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AccessContextManagerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccessPoliciesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AccessLevelsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: AccessLevel = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self,
                *,
                name: str,
                accessLevelFormat: typing_extensions.Literal[
                    "LEVEL_FORMAT_UNSPECIFIED", "AS_DEFINED", "CEL"
                ] = ...,
                **kwargs: typing.Any
            ) -> AccessLevelHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                accessLevelFormat: typing_extensions.Literal[
                    "LEVEL_FORMAT_UNSPECIFIED", "AS_DEFINED", "CEL"
                ] = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAccessLevelsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAccessLevelsResponseHttpRequest,
                previous_response: ListAccessLevelsResponse,
            ) -> ListAccessLevelsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: AccessLevel = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def replaceAll(
                self,
                *,
                parent: str,
                body: ReplaceAccessLevelsRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...

        @typing.type_check_only
        class ServicePerimetersResource(googleapiclient.discovery.Resource):
            def commit(
                self,
                *,
                parent: str,
                body: CommitServicePerimetersRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def create(
                self, *, parent: str, body: ServicePerimeter = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> ServicePerimeterHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListServicePerimetersResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListServicePerimetersResponseHttpRequest,
                previous_response: ListServicePerimetersResponse,
            ) -> ListServicePerimetersResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: ServicePerimeter = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def replaceAll(
                self,
                *,
                parent: str,
                body: ReplaceServicePerimetersRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...

        def create(
            self, *, body: AccessPolicy = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def delete(
            self, *, name: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> AccessPolicyHttpRequest: ...
        def getIamPolicy(
            self,
            *,
            resource: str,
            body: GetIamPolicyRequest = ...,
            **kwargs: typing.Any
        ) -> PolicyHttpRequest: ...
        def list(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            parent: str = ...,
            **kwargs: typing.Any
        ) -> ListAccessPoliciesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListAccessPoliciesResponseHttpRequest,
            previous_response: ListAccessPoliciesResponse,
        ) -> ListAccessPoliciesResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            name: str,
            body: AccessPolicy = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def setIamPolicy(
            self,
            *,
            resource: str,
            body: SetIamPolicyRequest = ...,
            **kwargs: typing.Any
        ) -> PolicyHttpRequest: ...
        def testIamPermissions(
            self,
            *,
            resource: str,
            body: TestIamPermissionsRequest = ...,
            **kwargs: typing.Any
        ) -> TestIamPermissionsResponseHttpRequest: ...
        def accessLevels(self) -> AccessLevelsResource: ...
        def servicePerimeters(self) -> ServicePerimetersResource: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def cancel(
            self, *, name: str, body: CancelOperationRequest = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            name: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListOperationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListOperationsResponseHttpRequest,
            previous_response: ListOperationsResponse,
        ) -> ListOperationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class GcpUserAccessBindingsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GcpUserAccessBinding = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GcpUserAccessBindingHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListGcpUserAccessBindingsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListGcpUserAccessBindingsResponseHttpRequest,
                previous_response: ListGcpUserAccessBindingsResponse,
            ) -> ListGcpUserAccessBindingsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GcpUserAccessBinding = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def gcpUserAccessBindings(self) -> GcpUserAccessBindingsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accessPolicies(self) -> AccessPoliciesResource: ...
    def operations(self) -> OperationsResource: ...
    def organizations(self) -> OrganizationsResource: ...

@typing.type_check_only
class AccessLevelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccessLevel: ...

@typing.type_check_only
class AccessPolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccessPolicy: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GcpUserAccessBindingHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GcpUserAccessBinding: ...

@typing.type_check_only
class ListAccessLevelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAccessLevelsResponse: ...

@typing.type_check_only
class ListAccessPoliciesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAccessPoliciesResponse: ...

@typing.type_check_only
class ListGcpUserAccessBindingsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGcpUserAccessBindingsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListServicePerimetersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListServicePerimetersResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class ServicePerimeterHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ServicePerimeter: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1Claim(
    typing_extensions.TypedDict, total=False
):
    claimDate: str
    claimReview: _list[GoogleFactcheckingFactchecktoolsV1alpha1ClaimReview]
    claimant: str
    text: str

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1ClaimAuthor(
    typing_extensions.TypedDict, total=False
):
    imageUrl: str
    jobTitle: str
    name: str
    sameAs: str

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1ClaimRating(
    typing_extensions.TypedDict, total=False
):
    bestRating: int
    imageUrl: str
    ratingExplanation: str
    ratingValue: int
    textualRating: str
    worstRating: int

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1ClaimReview(
    typing_extensions.TypedDict, total=False
):
    languageCode: str
    publisher: GoogleFactcheckingFactchecktoolsV1alpha1Publisher
    reviewDate: str
    textualRating: str
    title: str
    url: str

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewAuthor(
    typing_extensions.TypedDict, total=False
):
    imageUrl: str
    name: str

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkup(
    typing_extensions.TypedDict, total=False
):
    claimAppearances: _list[str]
    claimAuthor: GoogleFactcheckingFactchecktoolsV1alpha1ClaimAuthor
    claimDate: str
    claimFirstAppearance: str
    claimLocation: str
    claimReviewed: str
    rating: GoogleFactcheckingFactchecktoolsV1alpha1ClaimRating
    url: str

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkupPage(
    typing_extensions.TypedDict, total=False
):
    claimReviewAuthor: GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewAuthor
    claimReviewMarkups: _list[GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkup]
    name: str
    pageUrl: str
    publishDate: str
    versionId: str

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1FactCheckedClaimSearchResponse(
    typing_extensions.TypedDict, total=False
):
    claims: _list[GoogleFactcheckingFactchecktoolsV1alpha1Claim]
    nextPageToken: str

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1ListClaimReviewMarkupPagesResponse(
    typing_extensions.TypedDict, total=False
):
    claimReviewMarkupPages: _list[
        GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkupPage
    ]
    nextPageToken: str

@typing.type_check_only
class GoogleFactcheckingFactchecktoolsV1alpha1Publisher(
    typing_extensions.TypedDict, total=False
):
    name: str
    site: str

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...
